//
//  ContentView.swift
//  colorShape
//
//  Created by Pete Keleher on 9/27/21.
//

import SwiftUI


extension CGPoint: CustomStringConvertible {
    public var description: String { String(format: "(%.2f,%.2f)",x,y) }
}

struct DragGestureView: View {

    @State private var current: CGSize = .zero
    @State private var startPoint: CGPoint = .zero
    @State private var endPoint: CGPoint = .zero
    
    var drag: some Gesture {
        DragGesture(minimumDistance: 10.0, coordinateSpace: .global)
            .onEnded { v in
                self.startPoint = v.startLocation
                self.endPoint = v.location
                self.current = CGSize(
                    width: self.current.width + v.translation.width,     // <==
                    height: self.current.height + v.translation.height ) // <==
            }
            .onChanged { v in
                self.startPoint = v.location
            }
    }

    var body: some View {
        VStack {
            Text("Drag!")
            .frame(maxWidth:.infinity,maxHeight: .infinity)
            .offset(x: self.current.width, y: self.current.height)
            .gesture(drag)
            Text("Dragged from \(startPoint)" as String)
            Text("Dragged to \(endPoint)" as String)
        }
    }
}



struct FontColorView: View {
    var body: some View {
        VStack {
          Text("Large Red Title")
             .font(.largeTitle).foregroundColor(.red)
          Text("Green Title")
             .font(.title).foregroundColor(.green)
          Text("Blue Title2")
             .font(.title2).foregroundColor(.blue)
          Text("Orange Title3")
             .font(.title3).foregroundColor(.orange)
          Text("Purple Headline")
             .font(.headline).foregroundColor(.purple)
          Text("Gray Subheadline")
             .font(.subheadline).background(Color.gray)
          Text("Pink Body")
             .font(.body).background(Color.pink)
          Text("Yellow Callout")
             .font(.callout).background(Color.yellow)
          Text("Secondary Caption")
             .font(.caption).background(Color.secondary)
          Text("White on Black Caption2").font(.caption2)
            .foregroundColor(.white).background(Color.black)
        }
    }
}

struct ShapeView: View {
   var body: some View {
       VStack {
           HStack {
               Text("Circle").font(.title3)
               Circle().foregroundColor(.blue).frame(width:150,height:100)
            }
            HStack{
                Text("Ellipse").font(.title3)
                Ellipse().foregroundColor(.red).frame(width:150,height:100)
            }
            HStack {
                Text("Capsule").font(.title3)
                Capsule().foregroundColor(.green).frame(width:150,height:100)
            }
            HStack {
                Text("RoundedRectangle").font(.title3)
                RoundedRectangle(cornerRadius: 25.0)
                .foregroundColor(.purple).frame(width:150,height:100)
            }
            HStack {
                Text("Rectangle").font(.title3)
                Rectangle().foregroundColor(.orange)
                .frame(width:150,height:100)
            }
        }
    }
}

struct RotateView : View {
    var body: some View {
        VStack {
            HStack {
                Text("0 degrees").font(.title3)
                Spacer()
                Rectangle()
                    .frame(width: 150, height: 100)
                    .foregroundColor(.red)
                    .rotationEffect(.zero)
            }
            .padding()
            Spacer()
            HStack {
                Text("30 degrees")
                    .font(.title3)
                Spacer()
                Rectangle()
                    .frame(width: 150, height: 100)
                    .foregroundColor(.green)
                    .rotationEffect(Angle.degrees(30))
            }
            .padding()
            Spacer()
            HStack {
                Text("60 degrees").font(.title3)
                Spacer()
                Rectangle()
                    .frame(width: 150, height: 100)
                    .foregroundColor(.blue)
                    .rotationEffect(Angle.degrees(60))
            }
            .padding()
            Spacer()
        }
    }
}

struct ZView: View {
    var body: some View {
        ZStack {
           Rectangle().frame(width:200,height:100)
              .foregroundColor(.blue)
           Rectangle().frame(width:100,height:70)
              .foregroundColor(Color(red:0,green:1,blue:0,opacity:0.3))
              .rotationEffect(Angle.degrees(45))
           Circle().frame(width:50,height:50)
              .foregroundColor(.red)
              .offset(x: 40, y: 20)
         }
    }
}

struct ContentView: View {
    var body: some View {
        TabView {
            DragGestureView()
                .padding()
                .tabItem{ Text("Drag").font(.title)}
            FontColorView()
                .padding()
                .tabItem { Text("Font") }
            ShapeView()
                .padding()
                .tabItem { Text("Shapes") }
            RotateView()
                .padding()
                .tabItem { Text("Rotate") }
            ZView()
                .padding()
                .tabItem { Text("Z axis") }
        }
    }
}


struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}
